/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package zswzg.kex.tls;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;

import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Klasse für die Speicherung der Informationen eines Konfigurationsobjektes vom Typ typ.anzeigeAktorTls.
 *
 * @version $Revision: 1.1 $ / $Date: 2008/09/15 08:37:49 $ / ($Author: Drapp $)
 *
 * @author Dambach-Werke GmbH
 * @author Thomas Drapp
 *
 */
public class AnzeigeAktorTls
{
  /**
   * Konfigurationsobjekt vom Typ typ.anzeigeAktorTls.
   */
  SystemObject m_anzeigeAktorTls;
  /**
   * Konfigurationsobjekt vom Typ typ.anzeige das der Aktor umsetzt.
   */
  SystemObject m_anzeige;
  /**
   * Instanz der Klasse mit den Umsetzung-Informationen.
   */
  AnzeigeTypUmsetzungTls m_anzeigeTypUmsetzung;
  /**
   * DE's die den Aktor realisieren.
   */
  HashMap<String, SystemObject> m_des = new HashMap<String, SystemObject>();
  /**
   * Konfigurationsobjekt vom Typ typ.eak an den die DE gekoppelt ist.
   */
  SystemObject m_eak;

  /**
   * Konstruktor mit Übergabe des Konfigurationsobjektes.
   *
   * @param anzeigeAktorTls Konfigurationsobjekt über das der Aktor versorgt ist.
   */
  public AnzeigeAktorTls(SystemObject anzeigeAktorTls)
  {
    m_anzeigeAktorTls = anzeigeAktorTls;
  }
  
  /**
   * Holen der Pid des AnzeigeAktorTls.
   * 
   * @return Pid des AnzeigeAktorTls.
   */
  public String getPid()
  {
    if (m_anzeigeAktorTls != null)
      return m_anzeigeAktorTls.getPid();
    else
      return null;
  }

  /**
   * Holen der Anzeige die der Aktor umsetzt.
   * 
   * @return Anzeige die der Aktor umsetzt.
   */
  public SystemObject getAnzeige()
  {
    return m_anzeige;
  }
  
  /**
   * Setzen der Anzeige die der Aktor umsetzt.
   * 
   * @param anzeige Anzeige die der Aktor umsetzt.
   */
  public void setAnzeige(SystemObject anzeige)
  {
    m_anzeige = anzeige;
  }
  
  /**
   * Holen der Instanz der Klasse mit den Umsetzung-Informationen.
   * 
   * @return Instanz der Klasse mit den Umsetzung-Iinformationen.
   */
  public AnzeigeTypUmsetzungTls getAnzeigeTypUmsetzung()
  {
    return m_anzeigeTypUmsetzung;
  }
  
  /**
   * Setzen der Instanz der Klasse mit den Umsetzung-Informationen.
   * 
   * @param anzeigeTypUmsetzung Instanz der Klasse mit den Umsetzung-Informationen.
   */
  public void setAnzeigeTypUmsetzung(AnzeigeTypUmsetzungTls anzeigeTypUmsetzung)
  {
    m_anzeigeTypUmsetzung = anzeigeTypUmsetzung;
  }
  
  /**
   * Holen der HashMap mit den Konfigurationsobjekten vom Typ typ.de die den Aktor realisieren.
   * 
   * @return HashMap mit den Konfigurationsobjekten vom Typ typ.de die den Aktor realisieren.
   */
  public HashMap<String, SystemObject> getDes()
  {
    return m_des;
  }
  
  /**
   * Setzen der HashMap mit den Konfigurationsobjekten vom Typ typ.de die den Aktor realisieren.
   * 
   * @param des HashMap mit den Konfigurationsobjekten vom Typ typ.de die den Aktor realisieren.
   */
  public void setDes(HashMap<String, SystemObject> des)
  {
    m_des = des;
  }

  /**
   * Holen des Konfigurationsobjekt vom Typ typ.eak an den die DE gekoppelt ist.
   * 
   * @return Konfigurationsobjekt vom Typ typ.eak an den die DE gekoppelt ist.
   */
  public SystemObject getEak()
  {
    return m_eak;
  }

  /**
   * Setzen des Konfigurationsobjekt vom Typ typ.eak an den die DE gekoppelt ist.
   * 
   * @param eak Konfigurationsobjekt vom Typ typ.eak an den die DE gekoppelt ist.
   */
  public void setEak(SystemObject eak)
  {
    m_eak = eak;
  }

  /* (non-Javadoc)
   * @see java.lang.Object#toString()
   */
  @Override
  public String toString()
  {
    String string = new String();

    string += "AnzeigeAktorTls";
    string += " pid " + getPid();

    if (m_anzeige != null)
    	string += ", Anzeige " + m_anzeige.getPid();

    if (m_anzeigeTypUmsetzung != null)
    	string += ", AnzeigeTypUmsetzung " + m_anzeigeTypUmsetzung.getPid();
    
    string += ", DEs: ";
    
    Set<String> liste = m_des.keySet();
    
    Iterator<String> iterator = liste.iterator();
    
    if (iterator.hasNext())
    {
      string += ((SystemObject)m_des.get(iterator.next())).getPid();
    }
    
    while(iterator.hasNext())
    {
      string += ", " + ((SystemObject)m_des.get(iterator.next())).getPid();
    }

    return string;
  }
}
