/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package zswzg.kex.tls;

import java.util.HashMap;
import java.util.Vector;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Klasse für die Speicherung der Informationen eines Konfigurationsobjektes vom Typ typ.dirigentUmsetzungTls.
 *
 * @version $Revision: 1.1 $ / $Date: 2012/03/09 10:55:21 $ / ($Author: Drapp $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Thomas Drapp
 *
 */
public class DirigentUmsetzungTls
{
  /**
   * DebugLogger für Debug-Ausgaben.
   */
  private static Debug m_debug = Debug.getLogger();
  /**
   * Datenmodell.
   */
  protected DataModel m_dataModel;
  /**
   * Pid des Konfigurationsobjektes vom Typ typ.dirigentUmsetzungTls.
   */
  protected String m_pid;
  /**
   * Konfigurationsobjekt vom Typ typ.dirigentTypUmsetzung.
   */
  protected SystemObject m_dirigentUmsetzung;
  /**
   * HashMap mit Instanzen der Klasse ZeichenUmsetzungTls mit dem Schlüssel Code des Zeichen.
   */
  protected HashMap<Integer, ZeichenUmsetzungTls> m_listeZeichenUmsetzungTlsCode = new HashMap<Integer, ZeichenUmsetzungTls>();
  /**
   * HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls mit dem Schlüssel Pid des WvzInhalt.
   */
  protected HashMap<String, WvzInhaltUmsetzungTls> m_listeWvzInhaltUmsetzungTlsWvzInhalt = new HashMap<String, WvzInhaltUmsetzungTls>();
  /**
   * HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls mit dem Schlüssel Code des WvzInhalt.
   */
  protected HashMap<Integer, WvzInhaltUmsetzungTls> m_listeWvzInhaltUmsetzungTlsCode = new HashMap<Integer, WvzInhaltUmsetzungTls>();
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  protected Vector<GlobalUmsetzung> m_listeGlobalUmsetzung = new Vector<GlobalUmsetzung>();

  /**
   * Konstruktor mit Übergabe des Daten-Modell, der Pid der DirigentUmsetzung und dem Konfigurationsobjekt vom Typ typ.dirigentUmsetzung.
   *
   * @param dataModel Daten-Modell.
   * @param pid Pid der DirigentUmsetzung.
   * @param dirigentUmsetzung Konfigurationsobjekt vom Typ typ.dirigentUmsetzung.
   */
  public DirigentUmsetzungTls(DataModel dataModel, String pid, SystemObject dirigentUmsetzung)
  {
    m_dataModel = dataModel;
    m_pid = pid;
    m_dirigentUmsetzung = dirigentUmsetzung;

    AttributeGroup atgDirigentUmsetzung     = m_dataModel.getAttributeGroup("atg.dirigentUmsetzung");
    AttributeGroup atgDirigentUmsetzungTls  = m_dataModel.getAttributeGroup("atg.dirigentUmsetzungTls");
    AttributeGroup atgWvzInhaltUmsetzung    = m_dataModel.getAttributeGroup("atg.wvzInhaltUmsetzung");
    AttributeGroup atgWvzInhaltUmsetzungTls = m_dataModel.getAttributeGroup("atg.wvzInhaltUmsetzungTls");

    Data datenAtgDirigentUmsetzung = dirigentUmsetzung.getConfigurationData(atgDirigentUmsetzung);

    int anzahlWvzInhaltUmsetzungReferenz = datenAtgDirigentUmsetzung.getReferenceArray("WvzInhaltUmsetzungReferenz").getLength();

    SystemObject umsetzungWvzInhalt;
    Data datenAtgWvzInhaltUmsetzung;
    Data datenAtgWvzInhaltUmsetzungTls;
    int code;
    String pidWvzInhalt;

    for (int i = 0; i < anzahlWvzInhaltUmsetzungReferenz; i++)
    {
      umsetzungWvzInhalt = datenAtgDirigentUmsetzung.getReferenceArray("WvzInhaltUmsetzungReferenz").getReferenceValue(i).getSystemObject();

      datenAtgWvzInhaltUmsetzung    = umsetzungWvzInhalt.getConfigurationData(atgWvzInhaltUmsetzung);
      datenAtgWvzInhaltUmsetzungTls = umsetzungWvzInhalt.getConfigurationData(atgWvzInhaltUmsetzungTls);

      pidWvzInhalt  = datenAtgWvzInhaltUmsetzung.getReferenceValue("WvzInhaltReferenz").getValueText();

      ConfigurationObject objektAnzeigeInhalt = (ConfigurationObject)datenAtgWvzInhaltUmsetzung.getReferenceValue("WvzInhaltReferenz").getSystemObject();

      AttributeGroup atgWvzInhalt = ZwischenschichtAq.getConnection().getDataModel().getAttributeGroup("atg.wvzInhalt");

      Data dataWvzInhalt = objektAnzeigeInhalt.getConfigurationData(atgWvzInhalt);
      String wvzInhalt = dataWvzInhalt.getTextValue("Bildinhalt").getValueText();

      code = datenAtgWvzInhaltUmsetzungTls.getUnscaledValue("Code").intValue();

//      System.out.println("ANZEIGETYPUMSETZUNGTLS WvzInhaltUmsetzung '" + wvzInhalt + "' " + code);

      WvzInhaltUmsetzungTls wvzInhaltUmsetzungTls = new WvzInhaltUmsetzungTls(pidWvzInhalt, wvzInhalt, code);

      m_listeWvzInhaltUmsetzungTlsWvzInhalt.put(wvzInhalt, wvzInhaltUmsetzungTls);
      m_listeWvzInhaltUmsetzungTlsCode.put(code, wvzInhaltUmsetzungTls);
    }

    Data datenAtgDirigentUmsetzungTls = dirigentUmsetzung.getConfigurationData(atgDirigentUmsetzungTls);

    if (datenAtgDirigentUmsetzungTls != null)
    {
      int anzahlUmsetzungen = datenAtgDirigentUmsetzungTls.getArray("UmsetzungSchaltung").getLength();

      for (int i = 0; i < anzahlUmsetzungen; i++)
      {
        GlobalUmsetzung globalUmsetzung = new GlobalUmsetzung(datenAtgDirigentUmsetzungTls.getArray("UmsetzungSchaltung").getItem(i));

        m_listeGlobalUmsetzung.add(globalUmsetzung);
      }
    }
  }

  /**
   * Holen der Pid der AnzeigeTypUmsetzungTls.
   *
   * @return Pid der AnzeigeTypUmsetzungTls.
   */
  public String getPid()
  {
    return m_pid;
  }

  /**
   * Setzen der Pid der AnzeigeTypUmsetzungTls.
   *
   * @param pid Pid der AnzeigeTypUmsetzungTls.
   */
  public void setPid(String pid)
  {
    m_pid = pid;
  }

  /**
   * Holen des Konfigurationsobjektes vom Typ typ.dirigentUmsetzung.
   *
   * @return Konfigurationsobjekt vom Typ typ.dirigentUmsetzung.
   */
  public SystemObject getDirigentUmsetzung()
  {
    return m_dirigentUmsetzung;
  }

  /**
   * Setzen des Konfigurationsobjektes vom Typ typ.dirigentUmsetzung.
   *
   * @param dirigentUmsetzung Konfigurationsobjekt vom Typ typ.dirigentUmsetzung.
   */
  public void setDirigentUmsetzung(SystemObject dirigentUmsetzung)
  {
    m_dirigentUmsetzung = dirigentUmsetzung;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  public Vector getListeGlobalUmsetzung()
  {
    return m_listeGlobalUmsetzung;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   *
   * @param listeGlobalUmsetzung Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  public void setListeGlobalUmsetzung(Vector<GlobalUmsetzung> listeGlobalUmsetzung)
  {
    m_listeGlobalUmsetzung = listeGlobalUmsetzung;
  }

  /**
   * Holen der HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls mit dem Schlüssel Code des WVZ-Inhalt.
   *
   * @return HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls.
   */
  public HashMap getListeWvzInhaltUmsetzungTlsCode()
  {
    return m_listeWvzInhaltUmsetzungTlsCode;
  }

  /**
   * Holen der HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls mit dem Schlüssel Pid des WVZ-Inhalt.
   * 
   * @return HashMap mit Instanzen der Klasse WvzInhaltUmsetzungTls.
   */
  public HashMap getListeWvzInhaltUmsetzungTlsWvzInhalt()
  {
    return m_listeWvzInhaltUmsetzungTlsWvzInhalt;
  }
}