/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package zswzg.kex.tls;

/**
 * Klasse für die Speicherung der Informationen eines Konfigurationsobjektes vom Typ typ.zeichenUmsetzungTls.
 *
 * @version $Revision: 1.1 $ / $Date: 2008/09/15 08:37:49 $ / ($Author: Drapp $)
 *
 * @author Dambach-Werke GmbH
 * @author Thomas Drapp
 *
 */
public class ZeichenUmsetzungTls
{
  /**
   * Zeichencode auf TLS-Seite für das Zeichen.
   */
  int m_zeichencode;
  /**
   * Pid des Zeichens auf AnzeigenGlobal-Seite.
   */
  String m_pidZeichen;

  /**
   * Konstruktor mit Übergabe der Pid des Zeichen und dem Code des Zeichen.
   * 
   * @param zeichen Pid des Zeichens auf AnzeigenGlobal-Seite.
   * @param zeichencode Zeichencode des Zeichens auf TLS-Seite.
   */
  public ZeichenUmsetzungTls(String zeichen, int zeichencode)
  {
    m_pidZeichen = zeichen;
    m_zeichencode = zeichencode;
  }
  
  /**
   * Holen der Pid des Zeichens auf AnzeigenGlobal-Seite.
   * 
   * @return Pid des Zeichens auf AnzeigenGlobal-Seite.
   */
  public String getPidZeichen()
  {
    return m_pidZeichen;
  }
  
  /**
   * Setzen der Pid des Zeichens auf AnzeigenGlobal-Seite.
   * 
   * @param pidZeichen Pid des Zeichens auf AnzeigenGlobal-Seite.
   */
  public void setPidZeichen(String pidZeichen)
  {
    m_pidZeichen = pidZeichen;
  }
  
  /**
   * Holen des Zeichencode des Zeichens auf TLS-Seite.
   * 
   * @return Zeichencode des Zeichens auf TLS-Seite.
   */
  public int getZeichencode()
  {
    return m_zeichencode;
  }
  
  /**
   * Setzen des Zeichencode des Zeichens auf TLS-Seite.
   * 
   * @param zeichencode Zeichencode des Zeichens auf TLS-Seite.
   */
  public void setZeichencode(int zeichencode)
  {
    m_zeichencode = zeichencode;
  }
}
